==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/awscdk/CdkConfig.java <==
package io.github.cdklabs.projen.awscdk;

/**
 * (experimental) Represents cdk.json file.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.566Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.awscdk.CdkConfig")
public class CdkConfig extends io.github.cdklabs.projen.Component {

    protected CdkConfig(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CdkConfig(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public CdkConfig(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.awscdk.CdkConfigOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Name of the cdk.out directory.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getCdkout() {
        return software.amazon.jsii.Kernel.get(this, "cdkout", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) Represents the JSON file.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.JsonFile getJson() {
        return software.amazon.jsii.Kernel.get(this, "json", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.JsonFile.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.awscdk.CdkConfig}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.awscdk.CdkConfig> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.awscdk.CdkConfigOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.awscdk.CdkConfigOptions.Builder();
        }

        /**
         * (experimental) A command to execute before synthesis.
         * <p>
         * This command will be called when
         * running <code>cdk synth</code> or when <code>cdk watch</code> identifies a change in your source
         * code before redeployment.
         * <p>
         * Default: - no build command
         * <p>
         * @return {@code this}
         * @param buildCommand A command to execute before synthesis. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder buildCommand(final java.lang.String buildCommand) {
            this.options.buildCommand(buildCommand);
            return this;
        }

        /**
         * (experimental) cdk.out directory.
         * <p>
         * Default: "cdk.out"
         * <p>
         * @return {@code this}
         * @param cdkout cdk.out directory. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder cdkout(final java.lang.String cdkout) {
            this.options.cdkout(cdkout);
            return this;
        }

        /**
         * (experimental) Additional context to include in `cdk.json`.
         * <p>
         * Default: - no additional context
         * <p>
         * @return {@code this}
         * @param context Additional context to include in `cdk.json`. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder context(final java.util.Map<java.lang.String, java.lang.String> context) {
            this.options.context(context);
            return this;
        }

        /**
         * (experimental) Include all feature flags in cdk.json.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param featureFlags Include all feature flags in cdk.json. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder featureFlags(final java.lang.Boolean featureFlags) {
            this.options.featureFlags(featureFlags);
            return this;
        }

        /**
         * (experimental) To protect you against unintended changes that affect your security posture, the AWS CDK Toolkit prompts you to approve security-related changes before deploying them.
         * <p>
         * Default: ApprovalLevel.BROADENING
         * <p>
         * @return {@code this}
         * @param requireApproval To protect you against unintended changes that affect your security posture, the AWS CDK Toolkit prompts you to approve security-related changes before deploying them. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder requireApproval(final io.github.cdklabs.projen.awscdk.ApprovalLevel requireApproval) {
            this.options.requireApproval(requireApproval);
            return this;
        }

        /**
         * (experimental) Glob patterns to exclude from `cdk watch`.
         * <p>
         * Default: []
         * <p>
         * @return {@code this}
         * @param watchExcludes Glob patterns to exclude from `cdk watch`. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder watchExcludes(final java.util.List<java.lang.String> watchExcludes) {
            this.options.watchExcludes(watchExcludes);
            return this;
        }

        /**
         * (experimental) Glob patterns to include in `cdk watch`.
         * <p>
         * Default: []
         * <p>
         * @return {@code this}
         * @param watchIncludes Glob patterns to include in `cdk watch`. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder watchIncludes(final java.util.List<java.lang.String> watchIncludes) {
            this.options.watchIncludes(watchIncludes);
            return this;
        }

        /**
         * (experimental) The command line to execute in order to synthesize the CDK application (language specific).
         * <p>
         * @return {@code this}
         * @param app The command line to execute in order to synthesize the CDK application (language specific). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder app(final java.lang.String app) {
            this.options.app(app);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.awscdk.CdkConfig}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.awscdk.CdkConfig build() {
            return new io.github.cdklabs.projen.awscdk.CdkConfig(
                this.project,
                this.options.build()
            );
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/awscdk/CdkConfig.java <==
package io.github.cdklabs.projen.awscdk;

/**
 * (experimental) Represents cdk.json file.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.259Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.awscdk.CdkConfig")
public class CdkConfig extends io.github.cdklabs.projen.Component {

    protected CdkConfig(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CdkConfig(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public CdkConfig(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.awscdk.CdkConfigOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Add excludes to <code>cdk.json</code>.
     * <p>
     * @param patterns The excludes to add. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addExcludes(final @org.jetbrains.annotations.NotNull java.lang.String... patterns) {
        software.amazon.jsii.Kernel.call(this, "addExcludes", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(patterns).toArray(Object[]::new));
    }

    /**
     * (experimental) Add includes to <code>cdk.json</code>.
     * <p>
     * @param patterns The includes to add. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addIncludes(final @org.jetbrains.annotations.NotNull java.lang.String... patterns) {
        software.amazon.jsii.Kernel.call(this, "addIncludes", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(patterns).toArray(Object[]::new));
    }

    /**
     * (experimental) Name of the cdk.out directory.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getCdkout() {
        return software.amazon.jsii.Kernel.get(this, "cdkout", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) List of glob patterns to be excluded by CDK.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getExclude() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "exclude", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     * (experimental) List of glob patterns to be included by CDK.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getInclude() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "include", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     * (experimental) Represents the JSON file.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.JsonFile getJson() {
        return software.amazon.jsii.Kernel.get(this, "json", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.JsonFile.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.awscdk.CdkConfig}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.awscdk.CdkConfig> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.awscdk.CdkConfigOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.awscdk.CdkConfigOptions.Builder();
        }

        /**
         * (experimental) A command to execute before synthesis.
         * <p>
         * This command will be called when
         * running <code>cdk synth</code> or when <code>cdk watch</code> identifies a change in your source
         * code before redeployment.
         * <p>
         * Default: - no build command
         * <p>
         * @return {@code this}
         * @param buildCommand A command to execute before synthesis. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder buildCommand(final java.lang.String buildCommand) {
            this.options.buildCommand(buildCommand);
            return this;
        }

        /**
         * (experimental) cdk.out directory.
         * <p>
         * Default: "cdk.out"
         * <p>
         * @return {@code this}
         * @param cdkout cdk.out directory. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder cdkout(final java.lang.String cdkout) {
            this.options.cdkout(cdkout);
            return this;
        }

        /**
         * (experimental) Additional context to include in <code>cdk.json</code>.
         * <p>
         * Default: - no additional context
         * <p>
         * @return {@code this}
         * @param context Additional context to include in <code>cdk.json</code>. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder context(final java.util.Map<java.lang.String, ? extends java.lang.Object> context) {
            this.options.context(context);
            return this;
        }

        /**
         * (experimental) Include all feature flags in cdk.json.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param featureFlags Include all feature flags in cdk.json. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder featureFlags(final java.lang.Boolean featureFlags) {
            this.options.featureFlags(featureFlags);
            return this;
        }

        /**
         * (experimental) To protect you against unintended changes that affect your security posture, the AWS CDK Toolkit prompts you to approve security-related changes before deploying them.
         * <p>
         * Default: ApprovalLevel.BROADENING
         * <p>
         * @return {@code this}
         * @param requireApproval To protect you against unintended changes that affect your security posture, the AWS CDK Toolkit prompts you to approve security-related changes before deploying them. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder requireApproval(final io.github.cdklabs.projen.awscdk.ApprovalLevel requireApproval) {
            this.options.requireApproval(requireApproval);
            return this;
        }

        /**
         * (experimental) Glob patterns to exclude from <code>cdk watch</code>.
         * <p>
         * Default: []
         * <p>
         * @return {@code this}
         * @param watchExcludes Glob patterns to exclude from <code>cdk watch</code>. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder watchExcludes(final java.util.List<java.lang.String> watchExcludes) {
            this.options.watchExcludes(watchExcludes);
            return this;
        }

        /**
         * (experimental) Glob patterns to include in <code>cdk watch</code>.
         * <p>
         * Default: []
         * <p>
         * @return {@code this}
         * @param watchIncludes Glob patterns to include in <code>cdk watch</code>. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder watchIncludes(final java.util.List<java.lang.String> watchIncludes) {
            this.options.watchIncludes(watchIncludes);
            return this;
        }

        /**
         * (experimental) The command line to execute in order to synthesize the CDK application (language specific).
         * <p>
         * @return {@code this}
         * @param app The command line to execute in order to synthesize the CDK application (language specific). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder app(final java.lang.String app) {
            this.options.app(app);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.awscdk.CdkConfig}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.awscdk.CdkConfig build() {
            return new io.github.cdklabs.projen.awscdk.CdkConfig(
                this.project,
                this.options.build()
            );
        }
    }
}
